@@ -11,3 +11,11 @@ class RouteNotFoundError(EntitySDKError):
 
 class IteratorResultError(EntitySDKError):
     """Raised when the result of an iterator is not as expected."""
+
+
+class DependencyError(EntitySDKError):
+    """Raised when a dependency check fails."""
+
+
+class StagingError(EntitySDKError):
+    """Raised when a staging operation has failed."""
