@@ -1,10 +1,15 @@
 """Base model."""
 
-from typing import Self
+import sys
 
 from pydantic import BaseModel as PydanticBaseModel
 from pydantic import ConfigDict
 
+if sys.version_info < (3, 11):  # pragma: no cover
+    from typing_extensions import Self
+else:
+    from typing import Self
+
 
 class BaseModel(PydanticBaseModel):
     """Base model."""
@@ -13,6 +18,7 @@ class BaseModel(PydanticBaseModel):
         frozen=True,
         from_attributes=True,
         extra="ignore",
+        serialize_by_alias=True,
     )
 
     def evolve(self, **model_attributes) -> Self:
