@@ -1,7 +1,13 @@
 """Staging functions."""
 
 from entitysdk.staging.circuit import stage_circuit
+from entitysdk.staging.memodel import stage_sonata_from_memodel
 from entitysdk.staging.simulation import stage_simulation
 from entitysdk.staging.simulation_result import stage_simulation_result
 
-__all__ = ["stage_circuit", "stage_simulation", "stage_simulation_result"]
+__all__ = [
+    "stage_circuit",
+    "stage_sonata_from_memodel",
+    "stage_simulation",
+    "stage_simulation_result",
+]
