@@ -1,17 +1,20 @@
 import pytest
 
 from entitysdk.models import (
+    CellMorphology,
+    CellMorphologyProtocol,
     Contribution,
     ElectricalCellRecording,
     EModel,
+    IonChannel,
     IonChannelModel,
+    IonChannelRecording,
     License,
     MEModel,
     MEModelCalibrationResult,
     MTypeClass,
     Organization,
     Person,
-    ReconstructionMorphology,
     Role,
     SingleNeuronSimulation,
     SingleNeuronSynaptome,
@@ -25,12 +28,15 @@ from entitysdk.models import (
 @pytest.mark.parametrize(
     "entity_type",
     [
+        CellMorphology,
+        CellMorphologyProtocol,
         Contribution,
+        IonChannel,
         IonChannelModel,
+        IonChannelRecording,
         License,
         MTypeClass,
         Person,
-        ReconstructionMorphology,
         Role,
         Species,
         Strain,
