@@ -148,6 +148,7 @@ def _mock_asset_response(
         "meta": {},
         "sha256_digest": "sha256_digest",
         "label": label,
+        "storage_type": "aws_s3_internal",
     }
 
 
@@ -548,6 +549,7 @@ def _mock_asset_delete_response(asset_id):
         "meta": {},
         "id": str(asset_id),
         "status": "deleted",
+        "storage_type": "aws_s3_internal",
     }
 
 
@@ -581,6 +583,69 @@ def test_client_delete_asset(
     assert res.status == "deleted"
 
 
+@patch("entitysdk.route.get_route_name")
+def test_client_delete_asset__hard(
+    mock_route,
+    client,
+    httpx_mock,
+    api_url,
+    request_headers,
+):
+    mock_route.return_value = "cell-morphology"
+
+    entity_id = uuid.uuid4()
+    asset_id = uuid.uuid4()
+
+    httpx_mock.add_response(
+        method="DELETE",
+        url=f"{api_url}/cell-morphology/{entity_id}/assets/{asset_id}?hard=true",
+        match_headers=request_headers,
+        json=_mock_asset_delete_response(asset_id),
+    )
+
+    res = client.delete_asset(
+        entity_id=entity_id,
+        entity_type=None,
+        asset_id=asset_id,
+        hard=True,
+    )
+
+    assert res.id == asset_id
+    assert res.status == "deleted"
+
+
+@patch("entitysdk.route.get_route_name")
+def test_client_delete_asset__hard_admin(
+    mock_route,
+    client,
+    httpx_mock,
+    api_url,
+    request_headers,
+):
+    mock_route.return_value = "cell-morphology"
+
+    entity_id = uuid.uuid4()
+    asset_id = uuid.uuid4()
+
+    httpx_mock.add_response(
+        method="DELETE",
+        url=f"{api_url}/admin/cell-morphology/{entity_id}/assets/{asset_id}",
+        json=_mock_asset_delete_response(asset_id),
+    )
+
+    # ensure hard is ignored if admin = True because admin endpoint is always hard
+    res = client.delete_asset(
+        entity_id=entity_id,
+        entity_type=None,
+        asset_id=asset_id,
+        hard=True,
+        admin=True,
+    )
+
+    assert res.id == asset_id
+    assert res.status == "deleted"
+
+
 @patch("entitysdk.route.get_route_name")
 def test_client_update_asset(
     mock_route,
@@ -761,6 +826,7 @@ def test_client_download_assets__entity(
                 id=asset_id,
                 path="foo.json",
                 full_path="/foo/asset1",
+                storage_type=StorageType.aws_s3_internal,
                 is_directory=False,
                 content_type="application/json",
                 label="cell_composition_summary",
@@ -832,6 +898,7 @@ def test_upload_directory_by_paths(
         "sha256_digest": None,
         "size": -1,
         "status": "created",
+        "storage_type": "aws_s3_internal",
     }
     httpx_mock.add_response(
         method="POST",
@@ -1096,6 +1163,7 @@ def test_client_download_directory__asset(
         id=asset_id,
         path="path_to_asset",
         full_path="/circuit",
+        storage_type=StorageType.aws_s3_internal,
         is_directory=True,
         size=0,
         content_type="application/vnd.directory",
